@@ -42,7 +42,8 @@ pub fn safe_clone_config(config: &ValidatorConfig) -> ValidatorConfig {
         contact_debug_interval: config.contact_debug_interval,
         contact_save_interval: config.contact_save_interval,
         bpf_jit: config.bpf_jit,
-        send_transaction_service_config: config.send_transaction_service_config.clone(),
+        send_transaction_retry_ms: config.send_transaction_retry_ms,
+        send_transaction_leader_forward_count: config.send_transaction_leader_forward_count,
         no_poh_speed_test: config.no_poh_speed_test,
         poh_pinned_cpu_core: config.poh_pinned_cpu_core,
         account_indexes: config.account_indexes.clone(),
